==> aws-cdk-scala-kinesisfirehose_2.13-0.1.3-sources.jar: io/burkard/cdk/services/kinesisfirehose/SplunkDestinationConfigurationProperty.scala <==
package io.burkard.cdk.services.kinesisfirehose

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SplunkDestinationConfigurationProperty {

  def apply(
    hecEndpoint: Option[String] = None,
    hecAcknowledgmentTimeoutInSeconds: Option[Number] = None,
    cloudWatchLoggingOptions: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.CloudWatchLoggingOptionsProperty] = None,
    hecToken: Option[String] = None,
    s3Configuration: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.S3DestinationConfigurationProperty] = None,
    retryOptions: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.SplunkRetryOptionsProperty] = None,
    processingConfiguration: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.ProcessingConfigurationProperty] = None,
    hecEndpointType: Option[String] = None,
    s3BackupMode: Option[String] = None
  ): software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.SplunkDestinationConfigurationProperty =
    (new software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.SplunkDestinationConfigurationProperty.Builder)
      .hecEndpoint(hecEndpoint.orNull)
      .hecAcknowledgmentTimeoutInSeconds(hecAcknowledgmentTimeoutInSeconds.orNull)
      .cloudWatchLoggingOptions(cloudWatchLoggingOptions.orNull)
      .hecToken(hecToken.orNull)
      .s3Configuration(s3Configuration.orNull)
      .retryOptions(retryOptions.orNull)
      .processingConfiguration(processingConfiguration.orNull)
      .hecEndpointType(hecEndpointType.orNull)
      .s3BackupMode(s3BackupMode.orNull)
      .build()
}

==> aws-cdk-scala-kinesisfirehose_2.13-0.4.1-sources.jar: io/burkard/cdk/services/kinesisfirehose/SplunkDestinationConfigurationProperty.scala <==
package io.burkard.cdk.services.kinesisfirehose

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SplunkDestinationConfigurationProperty {

  def apply(
    hecEndpoint: String,
    hecToken: String,
    s3Configuration: software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.S3DestinationConfigurationProperty,
    hecEndpointType: String,
    hecAcknowledgmentTimeoutInSeconds: Option[Number] = None,
    cloudWatchLoggingOptions: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.CloudWatchLoggingOptionsProperty] = None,
    retryOptions: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.SplunkRetryOptionsProperty] = None,
    processingConfiguration: Option[software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.ProcessingConfigurationProperty] = None,
    s3BackupMode: Option[String] = None
  ): software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.SplunkDestinationConfigurationProperty =
    (new software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.SplunkDestinationConfigurationProperty.Builder)
      .hecEndpoint(hecEndpoint)
      .hecToken(hecToken)
      .s3Configuration(s3Configuration)
      .hecEndpointType(hecEndpointType)
      .hecAcknowledgmentTimeoutInSeconds(hecAcknowledgmentTimeoutInSeconds.orNull)
      .cloudWatchLoggingOptions(cloudWatchLoggingOptions.orNull)
      .retryOptions(retryOptions.orNull)
      .processingConfiguration(processingConfiguration.orNull)
      .s3BackupMode(s3BackupMode.orNull)
      .build()
}
